#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import sys
import json
import codecs

from Analyze import analyze_maya

try:
    channel
except:
    is_channel_exists = False
else:
    is_channel_exists = True
    
if is_channel_exists and channel == 'api':
    # api + linux
    # params in cmd: channel, options_json
    # params in options_json: cg_file, task_id, task_json, asset_json, tips_json, cg_project, cg_plugins, cg_version, channel
    with codecs.open(options_json, 'r', 'utf-8') as f_options_json:
        options = json.load(f_options_json)
else:
    #linux
    options = {}
    options["cg_file"] = cg_file
    options["cg_project"] = cg_project
    options["task_json"] = task_json
    if os.path.exists(options["task_json"]):
        options["asset_json"] = os.path.join(os.path.dirname(options["task_json"]),"asset.json").replace("\\","/")
        options["tips_json"] = os.path.join(os.path.dirname(options["task_json"]),"tips.json").replace("\\","/")
        options["system_json"] = os.path.join(os.path.dirname(options["task_json"]),"system.json").replace("\\","/")
        with codecs.open(options["task_json"],'r', 'utf-8') as f_task_json:
            task_json_dict = json.load(f_task_json)
        options["cg_version"] = task_json_dict['software_config']['cg_version']
        options["cg_plugins"] = task_json_dict['software_config']['plugins']
        with codecs.open(options["system_json"], 'r', 'utf-8') as f_system_json:
            system_json_dict = json.load(f_system_json)
        options["platform"] = system_json_dict['system_info']['common']['platform']
        options["channel"] = "web"
    else:
        print("task.json is not exists")
        sys.exit(555)
analyze_maya(options)



"""A Python-based API for Using Renderbus cloud rendering service."""

# pylint: disable=import-error
# Import third-party modules
from pkg_resources import DistributionNotFound, get_distribution

try:
    __version__ = get_distribution(__name__).version
except DistributionNotFound:
    # Package is not installed.
    __version__ = '1.4.0'



"""The plugin of the pytest.

The pytest plugin hooks do not need to be imported into any test code, it will
load automatically when running pytest.

References:
    https://docs.pytest.org/en/2.7.3/plugins.html

"""

# pylint: disable=import-error
import pytest

from rayvision_maya.analyze_maya import AnalyzeMaya


@pytest.fixture()
def analyze_info(tmpdir):
    """Get user info."""
    cg_file = str(tmpdir.join('muti_layer_test.ma'))
    with open(cg_file, "w"):
        pass
    return {
        "cg_file": cg_file,
        "workspace": str(tmpdir),
        "software_version": "2018",
        "project_name": "Project1",
        "plugin_config": {
            "mtoa": "3.1.2.1"
        }
    }


@pytest.fixture()
def maya_analyze(analyze_info):
    """Create an Maya object."""
    return AnalyzeMaya(**analyze_info)



#! /usr/bin/env python
#coding=utf-8
import sys
import os

script_version = "py" + "".join([str(i) for i in sys.version_info[:2]])
script_path = os.path.dirname(__file__)


sys.path.insert(0, script_path)

print("python executable is: " + sys.executable)
print("python version is: " + sys.version)
print("import Analyze path: " + script_path)
sys.stdout.flush()
print("from " + script_version + ".Analyze import *")
exec("from " + script_version + ".Analyze import *")



# -*- coding: utf-8 -*-

from rayvision_maya.analyze_maya import AnalyzeMaya

analyze_info = {
    "cg_file": r"D:\houdini\CG file\muti_layer_test.ma",
    "workspace": "c:/workspace",
    "software_version": "2018",
    "project_name": "Project1",
    "plugin_config": {
        "mtoa": "3.1.2.1"
    }
}

AnalyzeMaya(**analyze_info).analyse()
